You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@juddi.apache.org by ks...@apache.org on 2013/12/27 00:53:04 UTC

svn commit: r1553604 [2/2] - in /juddi/trunk: ./ juddi-client/src/main/java/org/apache/juddi/v3/client/config/ juddi-client/src/main/java/org/apache/juddi/v3/client/mapping/ juddi-client/src/main/java/org/apache/juddi/v3/client/transport/ juddi-client/...

Added: juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/example/wsdl2uddi/HelloWorldImpl.java
URL: http://svn.apache.org/viewvc/juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/example/wsdl2uddi/HelloWorldImpl.java?rev=1553604&view=auto
==============================================================================
--- juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/example/wsdl2uddi/HelloWorldImpl.java (added)
+++ juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/example/wsdl2uddi/HelloWorldImpl.java Thu Dec 26 23:53:03 2013
@@ -0,0 +1,34 @@
+/*
+ * Copyright 2001-2010 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ */
+package org.apache.juddi.example.wsdl2uddi;
+
+import javax.jws.WebService;
+
+import org.apache.juddi.samples.HelloWorld;
+
+@WebService(
+		endpointInterface = "org.apache.juddi.samples.HelloWorld",
+        serviceName = "HelloWorld")
+
+public class HelloWorldImpl implements HelloWorld {
+    
+    public String sayHi(String text) {
+        System.out.println("sayHi called");
+        return "Hello " + text;
+    }
+	
+}

Modified: juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/example/wsdl2uddi/Publish.java
URL: http://svn.apache.org/viewvc/juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/example/wsdl2uddi/Publish.java?rev=1553604&r1=1553603&r2=1553604&view=diff
==============================================================================
--- juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/HelloWorld.java (added)
+++ juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/HelloWorld.java Thu Dec 26 23:53:03 2013
@@ -0,0 +1,40 @@
+
+package org.apache.juddi.samples;
+
+import javax.jws.WebMethod;
+import javax.jws.WebParam;
+import javax.jws.WebResult;
+import javax.jws.WebService;
+import javax.xml.bind.annotation.XmlSeeAlso;
+import javax.xml.ws.RequestWrapper;
+import javax.xml.ws.ResponseWrapper;
+
+
+/**
+ * This class was generated by the JAX-WS RI.
+ * JAX-WS RI 2.2.4-b01
+ * Generated source version: 2.2
+ * 
+ */
+@WebService(name = "HelloWorld", targetNamespace = "http://samples.juddi.apache.org/")
+@XmlSeeAlso({
+    ObjectFactory.class
+})
+public interface HelloWorld {
+
+
+    /**
+     * 
+     * @param text
+     * @return
+     *     returns java.lang.String
+     */
+    @WebMethod
+    @WebResult(targetNamespace = "")
+    @RequestWrapper(localName = "sayHi", targetNamespace = "http://samples.juddi.apache.org/", className = "org.apache.juddi.samples.SayHi")
+    @ResponseWrapper(localName = "sayHiResponse", targetNamespace = "http://samples.juddi.apache.org/", className = "org.apache.juddi.samples.SayHiResponse")
+    public String sayHi(
+        @WebParam(name = "text", targetNamespace = "")
+        String text);
+
+}

Added: juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/HelloWorld_Service.java
URL: http://svn.apache.org/viewvc/juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/HelloWorld_Service.java?rev=1553604&view=auto
==============================================================================
--- juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/HelloWorld_Service.java (added)
+++ juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/HelloWorld_Service.java Thu Dec 26 23:53:03 2013
@@ -0,0 +1,86 @@
+
+package org.apache.juddi.samples;
+
+import java.net.URL;
+
+import javax.xml.namespace.QName;
+import javax.xml.ws.Service;
+import javax.xml.ws.WebEndpoint;
+import javax.xml.ws.WebServiceClient;
+import javax.xml.ws.WebServiceFeature;
+
+import org.apache.juddi.v3.client.ClassUtil;
+
+
+/**
+ * The Hello World Service registered using WSDL2UDDI
+ * 
+ * This class was generated by the JAX-WS RI.
+ * JAX-WS RI 2.2.4-b01
+ * Generated source version: 2.2
+ * 
+ */
+@WebServiceClient(name = "HelloWorld", targetNamespace = "http://samples.juddi.apache.org/", wsdlLocation = "src/main/resources/wsdl/helloworld.wsdl")
+public class HelloWorld_Service
+    extends Service
+{
+
+    private final static URL HELLOWORLD_WSDL_LOCATION;
+    
+    private final static QName HELLOWORLD_QNAME = new QName("http://samples.juddi.apache.org/", "HelloWorld");
+
+    static {
+    	HELLOWORLD_WSDL_LOCATION = ClassUtil.getResource("/wsdl/helloworld.wsdl",HelloWorld_Service.class);
+    }
+
+    public HelloWorld_Service() {
+        super(__getWsdlLocation(), HELLOWORLD_QNAME);
+    }
+
+    public HelloWorld_Service(WebServiceFeature... features) {
+        super(__getWsdlLocation(), HELLOWORLD_QNAME, features);
+    }
+
+    public HelloWorld_Service(URL wsdlLocation) {
+        super(wsdlLocation, HELLOWORLD_QNAME);
+    }
+
+    public HelloWorld_Service(URL wsdlLocation, WebServiceFeature... features) {
+        super(wsdlLocation, HELLOWORLD_QNAME, features);
+    }
+
+    public HelloWorld_Service(URL wsdlLocation, QName serviceName) {
+        super(wsdlLocation, serviceName);
+    }
+
+    public HelloWorld_Service(URL wsdlLocation, QName serviceName, WebServiceFeature... features) {
+        super(wsdlLocation, serviceName, features);
+    }
+
+    /**
+     * 
+     * @return
+     *     returns HelloWorld
+     */
+    @WebEndpoint(name = "HelloWorldImplPort")
+    public HelloWorld getHelloWorldImplPort() {
+        return super.getPort(new QName("http://samples.juddi.apache.org/", "HelloWorldImplPort"), HelloWorld.class);
+    }
+
+    /**
+     * 
+     * @param features
+     *     A list of {@link javax.xml.ws.WebServiceFeature} to configure on the proxy.  Supported features not in the <code>features</code> parameter will have their default values.
+     * @return
+     *     returns HelloWorld
+     */
+    @WebEndpoint(name = "HelloWorldImplPort")
+    public HelloWorld getHelloWorldImplPort(WebServiceFeature... features) {
+        return super.getPort(new QName("http://samples.juddi.apache.org/", "HelloWorldImplPort"), HelloWorld.class, features);
+    }
+
+    private static URL __getWsdlLocation() {
+        return HELLOWORLD_WSDL_LOCATION;
+    }
+
+}

Added: juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/ObjectFactory.java
URL: http://svn.apache.org/viewvc/juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/ObjectFactory.java?rev=1553604&view=auto
==============================================================================
--- juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/ObjectFactory.java (added)
+++ juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/ObjectFactory.java Thu Dec 26 23:53:03 2013
@@ -0,0 +1,71 @@
+
+package org.apache.juddi.samples;
+
+import javax.xml.bind.JAXBElement;
+import javax.xml.bind.annotation.XmlElementDecl;
+import javax.xml.bind.annotation.XmlRegistry;
+import javax.xml.namespace.QName;
+
+
+/**
+ * This object contains factory methods for each 
+ * Java content interface and Java element interface 
+ * generated in the org.apache.juddi.samples package. 
+ * <p>An ObjectFactory allows you to programatically 
+ * construct new instances of the Java representation 
+ * for XML content. The Java representation of XML 
+ * content can consist of schema derived interfaces 
+ * and classes representing the binding of schema 
+ * type definitions, element declarations and model 
+ * groups.  Factory methods for each of these are 
+ * provided in this class.
+ * 
+ */
+@XmlRegistry
+public class ObjectFactory {
+
+    private final static QName _SayHiResponse_QNAME = new QName("http://samples.juddi.apache.org/", "sayHiResponse");
+    private final static QName _SayHi_QNAME = new QName("http://samples.juddi.apache.org/", "sayHi");
+
+    /**
+     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.apache.juddi.samples
+     * 
+     */
+    public ObjectFactory() {
+    }
+
+    /**
+     * Create an instance of {@link SayHiResponse }
+     * 
+     */
+    public SayHiResponse createSayHiResponse() {
+        return new SayHiResponse();
+    }
+
+    /**
+     * Create an instance of {@link SayHi }
+     * 
+     */
+    public SayHi createSayHi() {
+        return new SayHi();
+    }
+
+    /**
+     * Create an instance of {@link JAXBElement }{@code <}{@link SayHiResponse }{@code >}}
+     * 
+     */
+    @XmlElementDecl(namespace = "http://samples.juddi.apache.org/", name = "sayHiResponse")
+    public JAXBElement<SayHiResponse> createSayHiResponse(SayHiResponse value) {
+        return new JAXBElement<SayHiResponse>(_SayHiResponse_QNAME, SayHiResponse.class, null, value);
+    }
+
+    /**
+     * Create an instance of {@link JAXBElement }{@code <}{@link SayHi }{@code >}}
+     * 
+     */
+    @XmlElementDecl(namespace = "http://samples.juddi.apache.org/", name = "sayHi")
+    public JAXBElement<SayHi> createSayHi(SayHi value) {
+        return new JAXBElement<SayHi>(_SayHi_QNAME, SayHi.class, null, value);
+    }
+
+}

Added: juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/SayHi.java
URL: http://svn.apache.org/viewvc/juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/SayHi.java?rev=1553604&view=auto
==============================================================================
--- juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/SayHi.java (added)
+++ juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/SayHi.java Thu Dec 26 23:53:03 2013
@@ -0,0 +1,60 @@
+
+package org.apache.juddi.samples;
+
+import javax.xml.bind.annotation.XmlAccessType;
+import javax.xml.bind.annotation.XmlAccessorType;
+import javax.xml.bind.annotation.XmlType;
+
+
+/**
+ * <p>Java class for sayHi complex type.
+ * 
+ * <p>The following schema fragment specifies the expected content contained within this class.
+ * 
+ * <pre>
+ * &lt;complexType name="sayHi">
+ *   &lt;complexContent>
+ *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
+ *       &lt;sequence>
+ *         &lt;element name="text" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *       &lt;/sequence>
+ *     &lt;/restriction>
+ *   &lt;/complexContent>
+ * &lt;/complexType>
+ * </pre>
+ * 
+ * 
+ */
+@XmlAccessorType(XmlAccessType.FIELD)
+@XmlType(name = "sayHi", propOrder = {
+    "text"
+})
+public class SayHi {
+
+    protected String text;
+
+    /**
+     * Gets the value of the text property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getText() {
+        return text;
+    }
+
+    /**
+     * Sets the value of the text property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setText(String value) {
+        this.text = value;
+    }
+
+}

Added: juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/SayHiResponse.java
URL: http://svn.apache.org/viewvc/juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/SayHiResponse.java?rev=1553604&view=auto
==============================================================================
--- juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/SayHiResponse.java (added)
+++ juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/SayHiResponse.java Thu Dec 26 23:53:03 2013
@@ -0,0 +1,62 @@
+
+package org.apache.juddi.samples;
+
+import javax.xml.bind.annotation.XmlAccessType;
+import javax.xml.bind.annotation.XmlAccessorType;
+import javax.xml.bind.annotation.XmlElement;
+import javax.xml.bind.annotation.XmlType;
+
+
+/**
+ * <p>Java class for sayHiResponse complex type.
+ * 
+ * <p>The following schema fragment specifies the expected content contained within this class.
+ * 
+ * <pre>
+ * &lt;complexType name="sayHiResponse">
+ *   &lt;complexContent>
+ *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
+ *       &lt;sequence>
+ *         &lt;element name="return" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *       &lt;/sequence>
+ *     &lt;/restriction>
+ *   &lt;/complexContent>
+ * &lt;/complexType>
+ * </pre>
+ * 
+ * 
+ */
+@XmlAccessorType(XmlAccessType.FIELD)
+@XmlType(name = "sayHiResponse", propOrder = {
+    "_return"
+})
+public class SayHiResponse {
+
+    @XmlElement(name = "return")
+    protected String _return;
+
+    /**
+     * Gets the value of the return property.
+     * 
+     * @return
+     *     possible object is
+     *     {@link String }
+     *     
+     */
+    public String getReturn() {
+        return _return;
+    }
+
+    /**
+     * Sets the value of the return property.
+     * 
+     * @param value
+     *     allowed object is
+     *     {@link String }
+     *     
+     */
+    public void setReturn(String value) {
+        this._return = value;
+    }
+
+}

Added: juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/package-info.java
URL: http://svn.apache.org/viewvc/juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/package-info.java?rev=1553604&view=auto
==============================================================================
--- juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/package-info.java (added)
+++ juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/package-info.java Thu Dec 26 23:53:03 2013
@@ -0,0 +1,2 @@
+@javax.xml.bind.annotation.XmlSchema(namespace = "http://samples.juddi.apache.org/")
+package org.apache.juddi.samples;

Modified: juddi/trunk/juddi-examples/wsdl2uddi/src/main/resources/META-INF/wsdl2uddi-uddi.xml
URL: http://svn.apache.org/viewvc/juddi/trunk/juddi-examples/wsdl2uddi/src/main/resources/META-INF/wsdl2uddi-uddi.xml?rev=1553604&r1=1553603&r2=1553604&view=diff
==============================================================================
--- juddi/trunk/juddi-examples/wsdl2uddi/src/main/resources/META-INF/wsdl2uddi-uddi.xml (original)
+++ juddi/trunk/juddi-examples/wsdl2uddi/src/main/resources/META-INF/wsdl2uddi-uddi.xml Thu Dec 26 23:53:03 2013
@@ -1,8 +1,8 @@
 <?xml version="1.0" encoding="ISO-8859-1" ?>
 
-<uddi>
+<uddi xmlns="urn:juddi-apache-org:v3_client" xsi:schemaLocation="classpath:/xsd/uddi-client.xsd">
     <reloadDelay>5000</reloadDelay>
-    <client name="example-client">
+    <client name="example-client" callbackUrl="http://localhost:8079/subscriptionlistener_uddi_client">
 		<nodes>
 			<node>
 			    <!-- required 'default' node -->
@@ -10,6 +10,8 @@
                 <properties>
                     <property name="serverName" value="localhost"/>
                     <property name="serverPort" value="8080"/>
+                    <property name="keyDomain" value="uddi.joepublisher.com"/>
+                    <property name="businessName" value="WSDL-Business"/>
 					<!-- for UDDI nodes that use HTTP u/p, using the following 
 					<property name="basicAuthUsername" value="root" />
 					<property name="basicAuthPassword" value="password" />
@@ -31,7 +33,7 @@
 		</nodes>
 		<clerks registerOnStartup="false">
            <clerk name="joe" node="default" publisher="joepublisher" password="joepublisher" isPasswordEncrypted="false" cryptoProvider="">
-              <wsdl businessKey="uddi:uddi.joepublisher.com:business-for-wsdl">wsdl/helloworld.wsdl</wsdl>
+              <wsdl businessName="WSDL-Business">wsdl/helloworld.wsdl</wsdl>
            </clerk>
         </clerks>
 	</client>

Added: juddi/trunk/juddi-examples/wsdl2uddi/src/main/resources/log4j.xml
URL: http://svn.apache.org/viewvc/juddi/trunk/juddi-examples/wsdl2uddi/src/main/resources/log4j.xml?rev=1553604&view=auto
==============================================================================
--- juddi/trunk/juddi-examples/wsdl2uddi/src/main/resources/log4j.xml (added)
+++ juddi/trunk/juddi-examples/wsdl2uddi/src/main/resources/log4j.xml Thu Dec 26 23:53:03 2013
@@ -0,0 +1,36 @@
+<?xml version="1.0" encoding="UTF-8" ?>
+<!DOCTYPE log4j:configuration SYSTEM "log4j.dtd">
+<log4j:configuration xmlns:log4j="http://jakarta.apache.org/log4j/" debug="false">
+    
+    <!-- ================================= -->
+    <!-- Preserve messages in a local file -->
+    <!-- ================================= -->
+    
+    <appender name="CONSOLE" class="org.apache.log4j.ConsoleAppender">
+      <param name="Target" value="System.out"/>
+      <param name="Threshold" value="DEBUG"/>
+
+      <layout class="org.apache.log4j.PatternLayout">
+         <!-- The default pattern: Date Priority [Category] Message\n -->
+         <param name="ConversionPattern" value="%d{ABSOLUTE} %-5p [%c{1}] %m%n"/>
+      </layout>
+   </appender>
+   
+    <logger name="org">
+        <level value="DEBUG"/>
+    </logger>
+    
+    <logger name="org.hibernate">
+        <level value="WARN"/>
+    </logger>
+
+    <logger name="com">
+        <level value="DEBUG"/>
+    </logger>
+    
+    <root>        
+          <appender-ref ref="CONSOLE"/>   
+    </root>
+    
+   
+</log4j:configuration>

Modified: juddi/trunk/juddi-examples/wsdl2uddi/src/main/resources/wsdl/helloworld.wsdl
URL: http://svn.apache.org/viewvc/juddi/trunk/juddi-examples/wsdl2uddi/src/main/resources/wsdl/helloworld.wsdl?rev=1553604&r1=1553603&r2=1553604&view=diff
==============================================================================
--- juddi/trunk/juddi-examples/wsdl2uddi/src/main/resources/wsdl/helloworld.wsdl (original)
+++ juddi/trunk/juddi-examples/wsdl2uddi/src/main/resources/wsdl/helloworld.wsdl Thu Dec 26 23:53:03 2013
@@ -47,7 +47,7 @@
   <wsdl:service name="HelloWorld">
     <wsdl:documentation>The Hello World Service registered using WSDL2UDDI</wsdl:documentation>
     <wsdl:port binding="tns:HelloWorldSoapBinding" name="HelloWorldImplPort">
-      <soap:address location="http://localhost:8080/uddi-annotations/services/helloworld"/>
+      <soap:address location="http://localhost:8080/services/helloworld"/>
     </wsdl:port>
   </wsdl:service>
 </wsdl:definitions>
\ No newline at end of file

Modified: juddi/trunk/juddi-gui/pom.xml
URL: http://svn.apache.org/viewvc/juddi/trunk/juddi-gui/pom.xml?rev=1553604&r1=1553603&r2=1553604&view=diff
==============================================================================
--- juddi/trunk/juddi-gui/pom.xml (original)
+++ juddi/trunk/juddi-gui/pom.xml Thu Dec 26 23:53:03 2013
@@ -130,5 +130,40 @@ language governing permissions and * lim
 			
 			
         </plugins>
+        <pluginManagement>
+        	<plugins>
+        		<!--This plugin's configuration is used to store Eclipse m2e settings only. It has no influence on the Maven build itself.-->
+        		<plugin>
+        			<groupId>org.eclipse.m2e</groupId>
+        			<artifactId>lifecycle-mapping</artifactId>
+        			<version>1.0.0</version>
+        			<configuration>
+        				<lifecycleMappingMetadata>
+        					<pluginExecutions>
+        						<pluginExecution>
+        							<pluginExecutionFilter>
+        								<groupId>
+        									org.apache.sling
+        								</groupId>
+        								<artifactId>
+        									maven-jspc-plugin
+        								</artifactId>
+        								<versionRange>
+        									[2.0.6,)
+        								</versionRange>
+        								<goals>
+        									<goal>jspc</goal>
+        								</goals>
+        							</pluginExecutionFilter>
+        							<action>
+        								<ignore></ignore>
+        							</action>
+        						</pluginExecution>
+        					</pluginExecutions>
+        				</lifecycleMappingMetadata>
+        			</configuration>
+        		</plugin>
+        	</plugins>
+        </pluginManagement>
     </build>
 </project>

Modified: juddi/trunk/pom.xml
URL: http://svn.apache.org/viewvc/juddi/trunk/pom.xml?rev=1553604&r1=1553603&r2=1553604&view=diff
==============================================================================
--- juddi/trunk/pom.xml (original)
+++ juddi/trunk/pom.xml Thu Dec 26 23:53:03 2013
@@ -173,7 +173,7 @@
                     <artifactId>maven-compiler-plugin</artifactId>
                     <configuration>
                         <source>1.6</source>
-                        <target>1.6</target>
+                        <target>1.7</target>
                     </configuration>
                 </plugin>
                 <plugin>



---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@juddi.apache.org
For additional commands, e-mail: commits-help@juddi.apache.org
--- juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/example/wsdl2uddi/Publish.java (original)
+++ juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/example/wsdl2uddi/Publish.java Thu Dec 26 23:53:03 2013
@@ -16,8 +16,12 @@
  */
 package org.apache.juddi.example.wsdl2uddi;
 
+import java.net.MalformedURLException;
+import java.net.URL;
 import java.rmi.RemoteException;
 
+import javax.xml.ws.Endpoint;
+
 import org.apache.commons.configuration.ConfigurationException;
 import org.apache.juddi.api_v3.Publisher;
 import org.apache.juddi.api_v3.SavePublisher;
@@ -48,29 +52,36 @@ public class Publish {
 		Name myBusName = new Name();
 		myBusName.setValue("WSDL-Business");
 		myBusEntity.getName().add(myBusName);
-		myBusEntity.setBusinessKey("uddi:uddi.joepublisher.com:business-for-wsdl");
+		myBusEntity.setBusinessKey("uddi:uddi.joepublisher.com:business_WSDL-Business");
 		clerk.register(myBusEntity);
 	}	
 	
-	public void publishWSDL(UDDIClerk clerk) {
+	public void publishWSDL(UDDIClerk clerk) throws MalformedURLException {
 		// Register the wsdls for this clerk, referenced in the wsdl2uddi-uddi.xml
-		clerk.registerWsdls();
+		clerk.registerWsdls(new URL("http://localhost:18080"));
 	}
 
 	public static void main (String args[]) {
 		
+		System.out.println("1. Bring up the hello world endpoint at port 18080");
+		Endpoint helloWorldEndPoint = Endpoint.create(new HelloWorldImpl());
+		helloWorldEndPoint.publish("http://localhost:18080/services/helloworld");
+		
+		System.out.println("2. Programmatically publish the endpoint to UDDI");
 		Publish sp = new Publish();
 		try {
 			uddiClient = new UDDIClient("META-INF/wsdl2uddi-uddi.xml");
 			UDDIClerk clerk = uddiClient.getClerk("joe");
 			
-			//setting up the publisher
+			System.out.println("setting up the publisher");
 			sp.setupJoePublisher(clerk);
-			//publish the business
+			System.out.println("publish the business");
 			sp.publishBusiness(clerk);
-			//and the wsdl
+			System.out.println("and the wsdl");
 			sp.publishWSDL(clerk);
 			
+			System.out.println("waiting for calls into the HelloWorldImpl...");
+			
 		} catch (Exception e) {
 			e.printStackTrace();
 		}
@@ -87,7 +98,7 @@ public class Publish {
 		getAuthTokenRoot.setCred("");
 		// Making API call that retrieves the authentication token for the 'root' user.
 		AuthToken rootAuthToken = security.getAuthToken(getAuthTokenRoot);
-		System.out.println ("root AUTHTOKEN = " + rootAuthToken.getAuthInfo());
+		System.out.println("root AUTHTOKEN = " + rootAuthToken.getAuthInfo());
 		//Creating joe publisher
 		JUDDIApiPortType juddiApi = uddiClient.getTransport("default").getJUDDIApiService();
 		Publisher p = new Publisher();
@@ -99,7 +110,7 @@ public class Publish {
 		sp.setAuthInfo(rootAuthToken.getAuthInfo());
 		juddiApi.savePublisher(sp);
 		
 		//Joe should have a keyGenerator
 		TModel keyGenerator = new TModel();
 		keyGenerator.setTModelKey("uddi:uddi.joepublisher.com:keygenerator");
 		Name name = new Name();
@@ -99,7 +110,7 @@ public class Publish {
 		juddiApi.savePublisher(sp);
 		
-		//Joe should have a keyGenerator
+		//Every publisher should have a keyGenerator, Joe has his:
 		TModel keyGenerator = new TModel();
 		keyGenerator.setTModelKey("uddi:uddi.joepublisher.com:keygenerator");

Added: juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/HelloWorld.java
URL: http://svn.apache.org/viewvc/juddi/trunk/juddi-examples/wsdl2uddi/src/main/java/org/apache/juddi/samples/HelloWorld.java?rev=1553604&view=auto
==============================================================================